@@ -5,7 +5,7 @@ echo "" 												>> $EXTENSION/build_order.txt
 	
 # Required
 [[ $(command -v gdbus) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
-[ ! -f /lib/libsigc-2.0.so ] && echo "Installing libsigcpp2" && extension --install libsigcpp2 && echo "Finished libsigcpp2"
+[ ! -f /lib/libsigc-3.0.so ] && echo "Installing libsigcpp:3.6.0" && extension --install libsigcpp:3.6.0 && echo "Finished libsigcpp:3.6.0"
 # Optional
 if [[ $INSTALL_OPTIONAL != false ]]; then 
 	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
@@ -17,10 +17,10 @@ if [[ $INSTALL_TESTS != false ]]; then
 	[[ $(command -v certtool) == "" ]] && echo "Installing gnutls" && extension --install gnutls && echo "Finished gnutls"
 fi
 
-if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libgiomm-2.4.so ]; then
-	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
+if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libgiomm-2.68.so ]; then
+	echo "glibmm_68" 									>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
-	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
+	echo "glibmm_68" 									>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 										>> $EXTENSION/build_order.txt
